MiniWorldMaker
==============

*Docs v.1.6.5.1*

MiniWorldMaker is a game-engine written in python and pygame designed for pupils to create 2D mini worlds and games.

```{toctree}
  :maxdepth: 1
mwm
tutorial_german
tutorial_english
api
key_concepts
examples
impressum
```

![Miniworldmaker](/_images/miniworldmaker.png)

Credits
---------

  * [Greenfoot](https://www.greenfoot.org/door): The model for this framework.

  * [Deepl](https://www.deepl.com/translator): Assistant for translating pages.
  
  * [Kenny Assets](https://www.kenney.nl/assets): Most of the images in the example-code are based on kenny assets. 

Links
-----

  * [Codeberg](https://codeberg.org/a_siebel/miniworldmaker)

  * [Examples](https://codeberg.org/a_siebel/miniworldmaker/src/branch/main/examples)